@@ -11,6 +11,8 @@
   # Check Java version.
   # See https://cran.r-project.org/doc/manuals/r-release/R-exts.html#Writing-portable-packages
   v <- rJava::.jcall("java/lang/System", "S", "getProperty", "java.runtime.version")
-  v <- as.numeric(paste0(strsplit(v, "[.]")[[1L]][1:2], collapse = "."))
-  if(v < 1.8) stop("Java 8 is required for this package.")
+  if(substr(v, 1L, 2L) == "1.") {
+    v <- as.numeric(paste0(strsplit(v, "[.]")[[1L]][1:2], collapse = "."))
+    if(v < 1.8) stop("Java 8 or above is required for this package.")
+  }
 }
